'''_1656.py

RollerBearingConicalProfile
'''


from mastapy._internal import constructor
from mastapy.bearings.roller_bearing_profiles import _1662
from mastapy._internal.python_net import python_net_import

_ROLLER_BEARING_CONICAL_PROFILE = python_net_import('SMT.MastaAPI.Bearings.RollerBearingProfiles', 'RollerBearingConicalProfile')


__docformat__ = 'restructuredtext en'
__all__ = ('RollerBearingConicalProfile',)


class RollerBearingConicalProfile(_1662.RollerBearingProfile):
    '''RollerBearingConicalProfile

    This is a mastapy class.
    '''

    TYPE = _ROLLER_BEARING_CONICAL_PROFILE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'RollerBearingConicalProfile.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def cone_angle(self) -> 'float':
        '''float: 'ConeAngle' is the original name of this property.'''

        return self.wrapped.ConeAngle

    @cone_angle.setter
    def cone_angle(self, value: 'float'):
        self.wrapped.ConeAngle = float(value) if value else 0.0

    @property
    def deviation_at_end_of_component(self) -> 'float':
        '''float: 'DeviationAtEndOfComponent' is the original name of this property.'''

        return self.wrapped.DeviationAtEndOfComponent

    @deviation_at_end_of_component.setter
    def deviation_at_end_of_component(self, value: 'float'):
        self.wrapped.DeviationAtEndOfComponent = float(value) if value else 0.0

    @property
    def deviation_offset(self) -> 'float':
        '''float: 'DeviationOffset' is the original name of this property.'''

        return self.wrapped.DeviationOffset

    @deviation_offset.setter
    def deviation_offset(self, value: 'float'):
        self.wrapped.DeviationOffset = float(value) if value else 0.0



'''_6601.py

KlingelnbergCycloPalloidHypoidGearSetLoadCase
'''


from typing import List

from mastapy.system_model.part_model.gears import _2246
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.static_loads import _6599, _6600, _6598
from mastapy._internal.python_net import python_net_import

_KLINGELNBERG_CYCLO_PALLOID_HYPOID_GEAR_SET_LOAD_CASE = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.StaticLoads', 'KlingelnbergCycloPalloidHypoidGearSetLoadCase')


__docformat__ = 'restructuredtext en'
__all__ = ('KlingelnbergCycloPalloidHypoidGearSetLoadCase',)


class KlingelnbergCycloPalloidHypoidGearSetLoadCase(_6598.KlingelnbergCycloPalloidConicalGearSetLoadCase):
    '''KlingelnbergCycloPalloidHypoidGearSetLoadCase

    This is a mastapy class.
    '''

    TYPE = _KLINGELNBERG_CYCLO_PALLOID_HYPOID_GEAR_SET_LOAD_CASE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'KlingelnbergCycloPalloidHypoidGearSetLoadCase.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def assembly_design(self) -> '_2246.KlingelnbergCycloPalloidHypoidGearSet':
        '''KlingelnbergCycloPalloidHypoidGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2246.KlingelnbergCycloPalloidHypoidGearSet)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def gears(self) -> 'List[_6599.KlingelnbergCycloPalloidHypoidGearLoadCase]':
        '''List[KlingelnbergCycloPalloidHypoidGearLoadCase]: 'Gears' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Gears, constructor.new(_6599.KlingelnbergCycloPalloidHypoidGearLoadCase))
        return value

    @property
    def klingelnberg_cyclo_palloid_hypoid_gears_load_case(self) -> 'List[_6599.KlingelnbergCycloPalloidHypoidGearLoadCase]':
        '''List[KlingelnbergCycloPalloidHypoidGearLoadCase]: 'KlingelnbergCycloPalloidHypoidGearsLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.KlingelnbergCycloPalloidHypoidGearsLoadCase, constructor.new(_6599.KlingelnbergCycloPalloidHypoidGearLoadCase))
        return value

    @property
    def klingelnberg_cyclo_palloid_hypoid_meshes_load_case(self) -> 'List[_6600.KlingelnbergCycloPalloidHypoidGearMeshLoadCase]':
        '''List[KlingelnbergCycloPalloidHypoidGearMeshLoadCase]: 'KlingelnbergCycloPalloidHypoidMeshesLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.KlingelnbergCycloPalloidHypoidMeshesLoadCase, constructor.new(_6600.KlingelnbergCycloPalloidHypoidGearMeshLoadCase))
        return value



'''_2235.py

FaceGear
'''


from mastapy.system_model.part_model.gears import _2238, _2237
from mastapy._internal import enum_with_selected_value_runtime, constructor, conversion
from mastapy.gears.gear_designs.face import _927, _932, _935
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_FACE_GEAR = python_net_import('SMT.MastaAPI.SystemModel.PartModel.Gears', 'FaceGear')


__docformat__ = 'restructuredtext en'
__all__ = ('FaceGear',)


class FaceGear(_2237.Gear):
    '''FaceGear

    This is a mastapy class.
    '''

    TYPE = _FACE_GEAR

    __hash__ = None

    def __init__(self, instance_to_wrap: 'FaceGear.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def orientation(self) -> '_2238.GearOrientations':
        '''GearOrientations: 'Orientation' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.Orientation)
        return constructor.new(_2238.GearOrientations)(value) if value else None

    @orientation.setter
    def orientation(self, value: '_2238.GearOrientations'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.Orientation = value

    @property
    def active_gear_design(self) -> '_927.FaceGearDesign':
        '''FaceGearDesign: 'ActiveGearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _927.FaceGearDesign.TYPE not in self.wrapped.ActiveGearDesign.__class__.__mro__:
            raise CastException('Failed to cast active_gear_design to FaceGearDesign. Expected: {}.'.format(self.wrapped.ActiveGearDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ActiveGearDesign.__class__)(self.wrapped.ActiveGearDesign) if self.wrapped.ActiveGearDesign else None

    @property
    def face_gear_design(self) -> '_927.FaceGearDesign':
        '''FaceGearDesign: 'FaceGearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _927.FaceGearDesign.TYPE not in self.wrapped.FaceGearDesign.__class__.__mro__:
            raise CastException('Failed to cast face_gear_design to FaceGearDesign. Expected: {}.'.format(self.wrapped.FaceGearDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.FaceGearDesign.__class__)(self.wrapped.FaceGearDesign) if self.wrapped.FaceGearDesign else None



'''_1510.py

CustomReportChart
'''


from mastapy._internal import constructor
from mastapy.utility.report import _1523, _1511
from mastapy._internal.python_net import python_net_import

_CUSTOM_REPORT_CHART = python_net_import('SMT.MastaAPI.Utility.Report', 'CustomReportChart')


__docformat__ = 'restructuredtext en'
__all__ = ('CustomReportChart',)


class CustomReportChart(_1523.CustomReportMultiPropertyItem['_1511.CustomReportChartItem']):
    '''CustomReportChart

    This is a mastapy class.
    '''

    TYPE = _CUSTOM_REPORT_CHART

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CustomReportChart.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def height(self) -> 'int':
        '''int: 'Height' is the original name of this property.'''

        return self.wrapped.Height

    @height.setter
    def height(self, value: 'int'):
        self.wrapped.Height = int(value) if value else 0

    @property
    def width(self) -> 'int':
        '''int: 'Width' is the original name of this property.'''

        return self.wrapped.Width

    @width.setter
    def width(self, value: 'int'):
        self.wrapped.Width = int(value) if value else 0



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._334 import ZerolBevelGearMeshRating
    from ._335 import ZerolBevelGearRating
    from ._336 import ZerolBevelGearSetRating



'''_5200.py

TorqueConverterConnectionMultibodyDynamicsAnalysis
'''


from mastapy._internal import constructor, enum_with_selected_value_runtime, conversion
from mastapy.system_model.analyses_and_results.mbd_analyses import _5204, _5109
from mastapy.system_model.connections_and_sockets.couplings import _2061
from mastapy.system_model.analyses_and_results.static_loads import _6658
from mastapy._internal.python_net import python_net_import

_TORQUE_CONVERTER_CONNECTION_MULTIBODY_DYNAMICS_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses', 'TorqueConverterConnectionMultibodyDynamicsAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('TorqueConverterConnectionMultibodyDynamicsAnalysis',)


class TorqueConverterConnectionMultibodyDynamicsAnalysis(_5109.CouplingConnectionMultibodyDynamicsAnalysis):
    '''TorqueConverterConnectionMultibodyDynamicsAnalysis

    This is a mastapy class.
    '''

    TYPE = _TORQUE_CONVERTER_CONNECTION_MULTIBODY_DYNAMICS_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'TorqueConverterConnectionMultibodyDynamicsAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def pump_torque(self) -> 'float':
        '''float: 'PumpTorque' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PumpTorque

    @property
    def turbine_torque(self) -> 'float':
        '''float: 'TurbineTorque' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TurbineTorque

    @property
    def speed_ratio(self) -> 'float':
        '''float: 'SpeedRatio' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SpeedRatio

    @property
    def torque_ratio(self) -> 'float':
        '''float: 'TorqueRatio' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TorqueRatio

    @property
    def capacity_factor_k(self) -> 'float':
        '''float: 'CapacityFactorK' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CapacityFactorK

    @property
    def inverse_capacity_factor_1k(self) -> 'float':
        '''float: 'InverseCapacityFactor1K' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.InverseCapacityFactor1K

    @property
    def locked_torque(self) -> 'float':
        '''float: 'LockedTorque' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LockedTorque

    @property
    def lock_up_viscous_torque(self) -> 'float':
        '''float: 'LockUpViscousTorque' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LockUpViscousTorque

    @property
    def is_locked(self) -> 'bool':
        '''bool: 'IsLocked' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.IsLocked

    @property
    def percentage_applied_pressure(self) -> 'float':
        '''float: 'PercentageAppliedPressure' is the original name of this property.'''

        return self.wrapped.PercentageAppliedPressure

    @percentage_applied_pressure.setter
    def percentage_applied_pressure(self, value: 'float'):
        self.wrapped.PercentageAppliedPressure = float(value) if value else 0.0

    @property
    def locking_status(self) -> '_5204.TorqueConverterStatus':
        '''TorqueConverterStatus: 'LockingStatus' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_enum(self.wrapped.LockingStatus)
        return constructor.new(_5204.TorqueConverterStatus)(value) if value else None

    @property
    def lock_up_clutch_temperature(self) -> 'float':
        '''float: 'LockUpClutchTemperature' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LockUpClutchTemperature

    @property
    def power_loss(self) -> 'float':
        '''float: 'PowerLoss' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PowerLoss

    @property
    def connection_design(self) -> '_2061.TorqueConverterConnection':
        '''TorqueConverterConnection: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2061.TorqueConverterConnection)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_load_case(self) -> '_6658.TorqueConverterConnectionLoadCase':
        '''TorqueConverterConnectionLoadCase: 'ConnectionLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6658.TorqueConverterConnectionLoadCase)(self.wrapped.ConnectionLoadCase) if self.wrapped.ConnectionLoadCase else None



'''_2651.py

ShaftHubConnectionCompoundSystemDeflection
'''


from typing import List

from mastapy.system_model.part_model.couplings import _2305
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.system_deflections import _2503
from mastapy.system_model.analyses_and_results.system_deflections.compound import _2589
from mastapy._internal.python_net import python_net_import

_SHAFT_HUB_CONNECTION_COMPOUND_SYSTEM_DEFLECTION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SystemDeflections.Compound', 'ShaftHubConnectionCompoundSystemDeflection')


__docformat__ = 'restructuredtext en'
__all__ = ('ShaftHubConnectionCompoundSystemDeflection',)


class ShaftHubConnectionCompoundSystemDeflection(_2589.ConnectorCompoundSystemDeflection):
    '''ShaftHubConnectionCompoundSystemDeflection

    This is a mastapy class.
    '''

    TYPE = _SHAFT_HUB_CONNECTION_COMPOUND_SYSTEM_DEFLECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ShaftHubConnectionCompoundSystemDeflection.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2305.ShaftHubConnection':
        '''ShaftHubConnection: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2305.ShaftHubConnection)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_analysis_cases_ready(self) -> 'List[_2503.ShaftHubConnectionSystemDeflection]':
        '''List[ShaftHubConnectionSystemDeflection]: 'ComponentAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ComponentAnalysisCasesReady, constructor.new(_2503.ShaftHubConnectionSystemDeflection))
        return value

    @property
    def planetaries(self) -> 'List[ShaftHubConnectionCompoundSystemDeflection]':
        '''List[ShaftHubConnectionCompoundSystemDeflection]: 'Planetaries' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Planetaries, constructor.new(ShaftHubConnectionCompoundSystemDeflection))
        return value

    @property
    def component_analysis_cases(self) -> 'List[_2503.ShaftHubConnectionSystemDeflection]':
        '''List[ShaftHubConnectionSystemDeflection]: 'ComponentAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ComponentAnalysisCases, constructor.new(_2503.ShaftHubConnectionSystemDeflection))
        return value



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._1848 import BearingDesign
    from ._1849 import DetailedBearing
    from ._1850 import DummyRollingBearing
    from ._1851 import LinearBearing
    from ._1852 import NonLinearBearing



'''_68.py

LinearDampingConnectionProperties
'''


from mastapy._internal import constructor
from mastapy.nodal_analysis import _43
from mastapy._internal.python_net import python_net_import

_LINEAR_DAMPING_CONNECTION_PROPERTIES = python_net_import('SMT.MastaAPI.NodalAnalysis', 'LinearDampingConnectionProperties')


__docformat__ = 'restructuredtext en'
__all__ = ('LinearDampingConnectionProperties',)


class LinearDampingConnectionProperties(_43.AbstractLinearConnectionProperties):
    '''LinearDampingConnectionProperties

    This is a mastapy class.
    '''

    TYPE = _LINEAR_DAMPING_CONNECTION_PROPERTIES

    __hash__ = None

    def __init__(self, instance_to_wrap: 'LinearDampingConnectionProperties.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def torsional_damping(self) -> 'float':
        '''float: 'TorsionalDamping' is the original name of this property.'''

        return self.wrapped.TorsionalDamping

    @torsional_damping.setter
    def torsional_damping(self, value: 'float'):
        self.wrapped.TorsionalDamping = float(value) if value else 0.0

    @property
    def radial_damping(self) -> 'float':
        '''float: 'RadialDamping' is the original name of this property.'''

        return self.wrapped.RadialDamping

    @radial_damping.setter
    def radial_damping(self, value: 'float'):
        self.wrapped.RadialDamping = float(value) if value else 0.0

    @property
    def axial_damping(self) -> 'float':
        '''float: 'AxialDamping' is the original name of this property.'''

        return self.wrapped.AxialDamping

    @axial_damping.setter
    def axial_damping(self, value: 'float'):
        self.wrapped.AxialDamping = float(value) if value else 0.0

    @property
    def tilt_damping(self) -> 'float':
        '''float: 'TiltDamping' is the original name of this property.'''

        return self.wrapped.TiltDamping

    @tilt_damping.setter
    def tilt_damping(self, value: 'float'):
        self.wrapped.TiltDamping = float(value) if value else 0.0



'''_2591.py

CouplingConnectionCompoundSystemDeflection
'''


from typing import List

from mastapy.system_model.analyses_and_results.system_deflections import _2431
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.system_deflections.compound import _2619
from mastapy._internal.python_net import python_net_import

_COUPLING_CONNECTION_COMPOUND_SYSTEM_DEFLECTION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SystemDeflections.Compound', 'CouplingConnectionCompoundSystemDeflection')


__docformat__ = 'restructuredtext en'
__all__ = ('CouplingConnectionCompoundSystemDeflection',)


class CouplingConnectionCompoundSystemDeflection(_2619.InterMountableComponentConnectionCompoundSystemDeflection):
    '''CouplingConnectionCompoundSystemDeflection

    This is a mastapy class.
    '''

    TYPE = _COUPLING_CONNECTION_COMPOUND_SYSTEM_DEFLECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CouplingConnectionCompoundSystemDeflection.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def connection_analysis_cases(self) -> 'List[_2431.CouplingConnectionSystemDeflection]':
        '''List[CouplingConnectionSystemDeflection]: 'ConnectionAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ConnectionAnalysisCases, constructor.new(_2431.CouplingConnectionSystemDeflection))
        return value

    @property
    def connection_analysis_cases_ready(self) -> 'List[_2431.CouplingConnectionSystemDeflection]':
        '''List[CouplingConnectionSystemDeflection]: 'ConnectionAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ConnectionAnalysisCasesReady, constructor.new(_2431.CouplingConnectionSystemDeflection))
        return value



'''_1295.py

GenericMatrix
'''


from typing import List, Generic, TypeVar

from mastapy._internal import constructor, conversion
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_GENERIC_MATRIX = python_net_import('SMT.MastaAPI.MathUtility', 'GenericMatrix')


__docformat__ = 'restructuredtext en'
__all__ = ('GenericMatrix',)


TElement = TypeVar('TElement', bound='object')
TMatrix = TypeVar('TMatrix', bound='GenericMatrix')


class GenericMatrix(_0.APIBase, Generic[TElement, TMatrix]):
    '''GenericMatrix

    This is a mastapy class.

    Generic Types:
        TElement
        TMatrix
    '''

    TYPE = _GENERIC_MATRIX

    __hash__ = None

    def __init__(self, instance_to_wrap: 'GenericMatrix.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def number_of_rows(self) -> 'int':
        '''int: 'NumberOfRows' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NumberOfRows

    @property
    def number_of_columns(self) -> 'int':
        '''int: 'NumberOfColumns' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NumberOfColumns

    @property
    def number_of_entries(self) -> 'int':
        '''int: 'NumberOfEntries' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NumberOfEntries

    @property
    def data(self) -> 'List[TElement]':
        '''List[TElement]: 'Data' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Data)
        return value



'''_3185.py

StraightBevelPlanetGearCompoundSteadyStateSynchronousResponseAtASpeed
'''


from typing import List

from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed import _3056
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed.compound import _3179
from mastapy._internal.python_net import python_net_import

_STRAIGHT_BEVEL_PLANET_GEAR_COMPOUND_STEADY_STATE_SYNCHRONOUS_RESPONSE_AT_A_SPEED = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SteadyStateSynchronousResponsesAtASpeed.Compound', 'StraightBevelPlanetGearCompoundSteadyStateSynchronousResponseAtASpeed')


__docformat__ = 'restructuredtext en'
__all__ = ('StraightBevelPlanetGearCompoundSteadyStateSynchronousResponseAtASpeed',)


class StraightBevelPlanetGearCompoundSteadyStateSynchronousResponseAtASpeed(_3179.StraightBevelDiffGearCompoundSteadyStateSynchronousResponseAtASpeed):
    '''StraightBevelPlanetGearCompoundSteadyStateSynchronousResponseAtASpeed

    This is a mastapy class.
    '''

    TYPE = _STRAIGHT_BEVEL_PLANET_GEAR_COMPOUND_STEADY_STATE_SYNCHRONOUS_RESPONSE_AT_A_SPEED

    __hash__ = None

    def __init__(self, instance_to_wrap: 'StraightBevelPlanetGearCompoundSteadyStateSynchronousResponseAtASpeed.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_analysis_cases_ready(self) -> 'List[_3056.StraightBevelPlanetGearSteadyStateSynchronousResponseAtASpeed]':
        '''List[StraightBevelPlanetGearSteadyStateSynchronousResponseAtASpeed]: 'ComponentAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ComponentAnalysisCasesReady, constructor.new(_3056.StraightBevelPlanetGearSteadyStateSynchronousResponseAtASpeed))
        return value

    @property
    def component_analysis_cases(self) -> 'List[_3056.StraightBevelPlanetGearSteadyStateSynchronousResponseAtASpeed]':
        '''List[StraightBevelPlanetGearSteadyStateSynchronousResponseAtASpeed]: 'ComponentAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ComponentAnalysisCases, constructor.new(_3056.StraightBevelPlanetGearSteadyStateSynchronousResponseAtASpeed))
        return value



'''_2421.py

ConceptCouplingSystemDeflection
'''


from mastapy.system_model.part_model.couplings import _2288
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.static_loads import _6521
from mastapy.system_model.analyses_and_results.power_flows import _3760
from mastapy.system_model.analyses_and_results.system_deflections import _2433
from mastapy._internal.python_net import python_net_import

_CONCEPT_COUPLING_SYSTEM_DEFLECTION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SystemDeflections', 'ConceptCouplingSystemDeflection')


__docformat__ = 'restructuredtext en'
__all__ = ('ConceptCouplingSystemDeflection',)


class ConceptCouplingSystemDeflection(_2433.CouplingSystemDeflection):
    '''ConceptCouplingSystemDeflection

    This is a mastapy class.
    '''

    TYPE = _CONCEPT_COUPLING_SYSTEM_DEFLECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ConceptCouplingSystemDeflection.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def assembly_design(self) -> '_2288.ConceptCoupling':
        '''ConceptCoupling: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2288.ConceptCoupling)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_load_case(self) -> '_6521.ConceptCouplingLoadCase':
        '''ConceptCouplingLoadCase: 'AssemblyLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6521.ConceptCouplingLoadCase)(self.wrapped.AssemblyLoadCase) if self.wrapped.AssemblyLoadCase else None

    @property
    def power_flow_results(self) -> '_3760.ConceptCouplingPowerFlow':
        '''ConceptCouplingPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_3760.ConceptCouplingPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None



'''_812.py

ConicalMeshLoadDistributionAtRotation
'''


from mastapy.gears.ltca import _785
from mastapy._internal.python_net import python_net_import

_CONICAL_MESH_LOAD_DISTRIBUTION_AT_ROTATION = python_net_import('SMT.MastaAPI.Gears.LTCA.Conical', 'ConicalMeshLoadDistributionAtRotation')


__docformat__ = 'restructuredtext en'
__all__ = ('ConicalMeshLoadDistributionAtRotation',)


class ConicalMeshLoadDistributionAtRotation(_785.GearMeshLoadDistributionAtRotation):
    '''ConicalMeshLoadDistributionAtRotation

    This is a mastapy class.
    '''

    TYPE = _CONICAL_MESH_LOAD_DISTRIBUTION_AT_ROTATION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ConicalMeshLoadDistributionAtRotation.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_6039.py

OilSealDynamicAnalysis
'''


from mastapy.system_model.part_model import _2174
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.static_loads import _6611
from mastapy.system_model.analyses_and_results.dynamic_analyses import _5996
from mastapy._internal.python_net import python_net_import

_OIL_SEAL_DYNAMIC_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.DynamicAnalyses', 'OilSealDynamicAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('OilSealDynamicAnalysis',)


class OilSealDynamicAnalysis(_5996.ConnectorDynamicAnalysis):
    '''OilSealDynamicAnalysis

    This is a mastapy class.
    '''

    TYPE = _OIL_SEAL_DYNAMIC_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'OilSealDynamicAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2174.OilSeal':
        '''OilSeal: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2174.OilSeal)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_load_case(self) -> '_6611.OilSealLoadCase':
        '''OilSealLoadCase: 'ComponentLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6611.OilSealLoadCase)(self.wrapped.ComponentLoadCase) if self.wrapped.ComponentLoadCase else None



'''_5930.py

StraightBevelGearCompoundHarmonicAnalysis
'''


from typing import List

from mastapy.system_model.part_model.gears import _2254
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.harmonic_analyses import _5765
from mastapy.system_model.analyses_and_results.harmonic_analyses.compound import _5838
from mastapy._internal.python_net import python_net_import

_STRAIGHT_BEVEL_GEAR_COMPOUND_HARMONIC_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.HarmonicAnalyses.Compound', 'StraightBevelGearCompoundHarmonicAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('StraightBevelGearCompoundHarmonicAnalysis',)


class StraightBevelGearCompoundHarmonicAnalysis(_5838.BevelGearCompoundHarmonicAnalysis):
    '''StraightBevelGearCompoundHarmonicAnalysis

    This is a mastapy class.
    '''

    TYPE = _STRAIGHT_BEVEL_GEAR_COMPOUND_HARMONIC_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'StraightBevelGearCompoundHarmonicAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2254.StraightBevelGear':
        '''StraightBevelGear: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2254.StraightBevelGear)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_analysis_cases_ready(self) -> 'List[_5765.StraightBevelGearHarmonicAnalysis]':
        '''List[StraightBevelGearHarmonicAnalysis]: 'ComponentAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ComponentAnalysisCasesReady, constructor.new(_5765.StraightBevelGearHarmonicAnalysis))
        return value

    @property
    def component_analysis_cases(self) -> 'List[_5765.StraightBevelGearHarmonicAnalysis]':
        '''List[StraightBevelGearHarmonicAnalysis]: 'ComponentAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ComponentAnalysisCases, constructor.new(_5765.StraightBevelGearHarmonicAnalysis))
        return value



'''_496.py

ConicalMeshDutyCycleRating
'''


from typing import List

from mastapy.gears.rating.conical import _491
from mastapy._internal import constructor, conversion
from mastapy.gears.rating import _330
from mastapy._internal.python_net import python_net_import

_CONICAL_MESH_DUTY_CYCLE_RATING = python_net_import('SMT.MastaAPI.Gears.Rating.Conical', 'ConicalMeshDutyCycleRating')


__docformat__ = 'restructuredtext en'
__all__ = ('ConicalMeshDutyCycleRating',)


class ConicalMeshDutyCycleRating(_330.MeshDutyCycleRating):
    '''ConicalMeshDutyCycleRating

    This is a mastapy class.
    '''

    TYPE = _CONICAL_MESH_DUTY_CYCLE_RATING

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ConicalMeshDutyCycleRating.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def conical_mesh_ratings(self) -> 'List[_491.ConicalGearMeshRating]':
        '''List[ConicalGearMeshRating]: 'ConicalMeshRatings' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ConicalMeshRatings, constructor.new(_491.ConicalGearMeshRating))
        return value



'''_5174.py

RootAssemblyMultibodyDynamicsAnalysis
'''


from mastapy._internal import constructor
from mastapy.system_model.part_model import _2182
from mastapy.system_model.analyses_and_results.mbd_analyses import _2346, _5077
from mastapy._internal.python_net import python_net_import

_ROOT_ASSEMBLY_MULTIBODY_DYNAMICS_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses', 'RootAssemblyMultibodyDynamicsAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('RootAssemblyMultibodyDynamicsAnalysis',)


class RootAssemblyMultibodyDynamicsAnalysis(_5077.AssemblyMultibodyDynamicsAnalysis):
    '''RootAssemblyMultibodyDynamicsAnalysis

    This is a mastapy class.
    '''

    TYPE = _ROOT_ASSEMBLY_MULTIBODY_DYNAMICS_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'RootAssemblyMultibodyDynamicsAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def log_10_time_step(self) -> 'float':
        '''float: 'Log10TimeStep' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Log10TimeStep

    @property
    def actual_torque_ratio(self) -> 'float':
        '''float: 'ActualTorqueRatio' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ActualTorqueRatio

    @property
    def actual_torque_ratio_turbine_to_output(self) -> 'float':
        '''float: 'ActualTorqueRatioTurbineToOutput' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ActualTorqueRatioTurbineToOutput

    @property
    def power_loss(self) -> 'float':
        '''float: 'PowerLoss' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PowerLoss

    @property
    def efficiency(self) -> 'float':
        '''float: 'Efficiency' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Efficiency

    @property
    def input_power(self) -> 'float':
        '''float: 'InputPower' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.InputPower

    @property
    def input_energy(self) -> 'float':
        '''float: 'InputEnergy' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.InputEnergy

    @property
    def energy_lost(self) -> 'float':
        '''float: 'EnergyLost' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.EnergyLost

    @property
    def overall_efficiency(self) -> 'float':
        '''float: 'OverallEfficiency' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.OverallEfficiency

    @property
    def vehicle_position(self) -> 'float':
        '''float: 'VehiclePosition' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.VehiclePosition

    @property
    def vehicle_speed(self) -> 'float':
        '''float: 'VehicleSpeed' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.VehicleSpeed

    @property
    def vehicle_drag(self) -> 'float':
        '''float: 'VehicleDrag' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.VehicleDrag

    @property
    def vehicle_acceleration(self) -> 'float':
        '''float: 'VehicleAcceleration' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.VehicleAcceleration

    @property
    def brake_force(self) -> 'float':
        '''float: 'BrakeForce' is the original name of this property.'''

        return self.wrapped.BrakeForce

    @brake_force.setter
    def brake_force(self, value: 'float'):
        self.wrapped.BrakeForce = float(value) if value else 0.0

    @property
    def road_incline(self) -> 'float':
        '''float: 'RoadIncline' is the original name of this property.'''

        return self.wrapped.RoadIncline

    @road_incline.setter
    def road_incline(self, value: 'float'):
        self.wrapped.RoadIncline = float(value) if value else 0.0

    @property
    def force_from_road_incline(self) -> 'float':
        '''float: 'ForceFromRoadIncline' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ForceFromRoadIncline

    @property
    def force_from_wheels(self) -> 'float':
        '''float: 'ForceFromWheels' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ForceFromWheels

    @property
    def total_force_on_vehicle(self) -> 'float':
        '''float: 'TotalForceOnVehicle' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TotalForceOnVehicle

    @property
    def maximum_vehicle_speed_error(self) -> 'float':
        '''float: 'MaximumVehicleSpeedError' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumVehicleSpeedError

    @property
    def vehicle_speed_drive_cycle_error(self) -> 'float':
        '''float: 'VehicleSpeedDriveCycleError' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.VehicleSpeedDriveCycleError

    @property
    def percentage_error_in_vehicle_speed_compared_to_drive_cycle(self) -> 'float':
        '''float: 'PercentageErrorInVehicleSpeedComparedToDriveCycle' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PercentageErrorInVehicleSpeedComparedToDriveCycle

    @property
    def current_target_vehicle_speed(self) -> 'float':
        '''float: 'CurrentTargetVehicleSpeed' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CurrentTargetVehicleSpeed

    @property
    def oil_dynamic_temperature(self) -> 'float':
        '''float: 'OilDynamicTemperature' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.OilDynamicTemperature

    @property
    def assembly_design(self) -> '_2182.RootAssembly':
        '''RootAssembly: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2182.RootAssembly)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def multibody_dynamics_analysis_inputs(self) -> '_2346.MultibodyDynamicsAnalysis':
        '''MultibodyDynamicsAnalysis: 'MultibodyDynamicsAnalysisInputs' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2346.MultibodyDynamicsAnalysis)(self.wrapped.MultibodyDynamicsAnalysisInputs) if self.wrapped.MultibodyDynamicsAnalysisInputs else None



'''_4927.py

ZerolBevelGearSetModalAnalysis
'''


from typing import List

from mastapy.system_model.part_model.gears import _2261
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.static_loads import _6673
from mastapy.system_model.analyses_and_results.system_deflections import _2542
from mastapy.system_model.analyses_and_results.modal_analyses import _4926, _4925, _4805
from mastapy._internal.python_net import python_net_import

_ZEROL_BEVEL_GEAR_SET_MODAL_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalyses', 'ZerolBevelGearSetModalAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('ZerolBevelGearSetModalAnalysis',)


class ZerolBevelGearSetModalAnalysis(_4805.BevelGearSetModalAnalysis):
    '''ZerolBevelGearSetModalAnalysis

    This is a mastapy class.
    '''

    TYPE = _ZEROL_BEVEL_GEAR_SET_MODAL_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ZerolBevelGearSetModalAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def assembly_design(self) -> '_2261.ZerolBevelGearSet':
        '''ZerolBevelGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2261.ZerolBevelGearSet)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_load_case(self) -> '_6673.ZerolBevelGearSetLoadCase':
        '''ZerolBevelGearSetLoadCase: 'AssemblyLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6673.ZerolBevelGearSetLoadCase)(self.wrapped.AssemblyLoadCase) if self.wrapped.AssemblyLoadCase else None

    @property
    def system_deflection_results(self) -> '_2542.ZerolBevelGearSetSystemDeflection':
        '''ZerolBevelGearSetSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2542.ZerolBevelGearSetSystemDeflection)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None

    @property
    def zerol_bevel_gears_modal_analysis(self) -> 'List[_4926.ZerolBevelGearModalAnalysis]':
        '''List[ZerolBevelGearModalAnalysis]: 'ZerolBevelGearsModalAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ZerolBevelGearsModalAnalysis, constructor.new(_4926.ZerolBevelGearModalAnalysis))
        return value

    @property
    def zerol_bevel_meshes_modal_analysis(self) -> 'List[_4925.ZerolBevelGearMeshModalAnalysis]':
        '''List[ZerolBevelGearMeshModalAnalysis]: 'ZerolBevelMeshesModalAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ZerolBevelMeshesModalAnalysis, constructor.new(_4925.ZerolBevelGearMeshModalAnalysis))
        return value



'''_4853.py

HypoidGearSetModalAnalysis
'''


from typing import List

from mastapy.system_model.part_model.gears import _2242
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.static_loads import _6591
from mastapy.system_model.analyses_and_results.system_deflections import _2466
from mastapy.system_model.analyses_and_results.modal_analyses import _4852, _4851, _4793
from mastapy._internal.python_net import python_net_import

_HYPOID_GEAR_SET_MODAL_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalyses', 'HypoidGearSetModalAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('HypoidGearSetModalAnalysis',)


class HypoidGearSetModalAnalysis(_4793.AGMAGleasonConicalGearSetModalAnalysis):
    '''HypoidGearSetModalAnalysis

    This is a mastapy class.
    '''

    TYPE = _HYPOID_GEAR_SET_MODAL_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'HypoidGearSetModalAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def assembly_design(self) -> '_2242.HypoidGearSet':
        '''HypoidGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2242.HypoidGearSet)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_load_case(self) -> '_6591.HypoidGearSetLoadCase':
        '''HypoidGearSetLoadCase: 'AssemblyLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6591.HypoidGearSetLoadCase)(self.wrapped.AssemblyLoadCase) if self.wrapped.AssemblyLoadCase else None

    @property
    def system_deflection_results(self) -> '_2466.HypoidGearSetSystemDeflection':
        '''HypoidGearSetSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2466.HypoidGearSetSystemDeflection)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None

    @property
    def hypoid_gears_modal_analysis(self) -> 'List[_4852.HypoidGearModalAnalysis]':
        '''List[HypoidGearModalAnalysis]: 'HypoidGearsModalAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.HypoidGearsModalAnalysis, constructor.new(_4852.HypoidGearModalAnalysis))
        return value

    @property
    def hypoid_meshes_modal_analysis(self) -> 'List[_4851.HypoidGearMeshModalAnalysis]':
        '''List[HypoidGearMeshModalAnalysis]: 'HypoidMeshesModalAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.HypoidMeshesModalAnalysis, constructor.new(_4851.HypoidGearMeshModalAnalysis))
        return value



'''_480.py

ISO6336MeanStressInfluenceFactor
'''


from mastapy._internal import constructor, enum_with_selected_value_runtime, conversion
from mastapy.gears import _288
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_ISO6336_MEAN_STRESS_INFLUENCE_FACTOR = python_net_import('SMT.MastaAPI.Gears.Rating.Cylindrical.ISO6336', 'ISO6336MeanStressInfluenceFactor')


__docformat__ = 'restructuredtext en'
__all__ = ('ISO6336MeanStressInfluenceFactor',)


class ISO6336MeanStressInfluenceFactor(_0.APIBase):
    '''ISO6336MeanStressInfluenceFactor

    This is a mastapy class.
    '''

    TYPE = _ISO6336_MEAN_STRESS_INFLUENCE_FACTOR

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ISO6336MeanStressInfluenceFactor.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def load_per_unit_face_width_of_the_lower_loaded_flank(self) -> 'float':
        '''float: 'LoadPerUnitFaceWidthOfTheLowerLoadedFlank' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LoadPerUnitFaceWidthOfTheLowerLoadedFlank

    @property
    def load_per_unit_face_width_of_the_higher_loaded_flank(self) -> 'float':
        '''float: 'LoadPerUnitFaceWidthOfTheHigherLoadedFlank' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LoadPerUnitFaceWidthOfTheHigherLoadedFlank

    @property
    def higher_loaded_flank(self) -> '_288.CylindricalFlanks':
        '''CylindricalFlanks: 'HigherLoadedFlank' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_enum(self.wrapped.HigherLoadedFlank)
        return constructor.new(_288.CylindricalFlanks)(value) if value else None

    @property
    def stress_ratio(self) -> 'float':
        '''float: 'StressRatio' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.StressRatio

    @property
    def mean_stress_ratio_for_static_stress(self) -> 'float':
        '''float: 'MeanStressRatioForStaticStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MeanStressRatioForStaticStress

    @property
    def mean_stress_ratio_for_reference_stress(self) -> 'float':
        '''float: 'MeanStressRatioForReferenceStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MeanStressRatioForReferenceStress

    @property
    def stress_influence_factor_for_reference_stress(self) -> 'float':
        '''float: 'StressInfluenceFactorForReferenceStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.StressInfluenceFactorForReferenceStress

    @property
    def stress_influence_factor(self) -> 'float':
        '''float: 'StressInfluenceFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.StressInfluenceFactor



'''_4571.py

CVTPulleyModalAnalysisAtASpeed
'''


from mastapy.system_model.part_model.couplings import _2294
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.modal_analyses_at_a_speed import _4617
from mastapy._internal.python_net import python_net_import

_CVT_PULLEY_MODAL_ANALYSIS_AT_A_SPEED = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalysesAtASpeed', 'CVTPulleyModalAnalysisAtASpeed')


__docformat__ = 'restructuredtext en'
__all__ = ('CVTPulleyModalAnalysisAtASpeed',)


class CVTPulleyModalAnalysisAtASpeed(_4617.PulleyModalAnalysisAtASpeed):
    '''CVTPulleyModalAnalysisAtASpeed

    This is a mastapy class.
    '''

    TYPE = _CVT_PULLEY_MODAL_ANALYSIS_AT_A_SPEED

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CVTPulleyModalAnalysisAtASpeed.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2294.CVTPulley':
        '''CVTPulley: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2294.CVTPulley)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None



'''_1691.py

BallBearingContactCalculation
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_BALL_BEARING_CONTACT_CALCULATION = python_net_import('SMT.MastaAPI.Bearings.BearingResults.Rolling', 'BallBearingContactCalculation')


__docformat__ = 'restructuredtext en'
__all__ = ('BallBearingContactCalculation',)


class BallBearingContactCalculation(Enum):
    '''BallBearingContactCalculation

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _BALL_BEARING_CONTACT_CALCULATION

    __hash__ = None

    FULL = 0
    BREWE_AND_HAMROCK_1977 = 1
    HAMROCK_AND_BREWE_1983 = 2


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


BallBearingContactCalculation.__setattr__ = __enum_setattr
BallBearingContactCalculation.__delattr__ = __enum_delattr



'''_2099.py

FESubstructureWithSelectionComponents
'''


from typing import List

from mastapy._internal import constructor, conversion
from mastapy.math_utility import _1280
from mastapy._math.vector_3d import Vector3D
from mastapy.system_model.fe.links import _2128
from mastapy.system_model.fe import (
    _2085, _2107, _2077, _2076,
    _2098
)
from mastapy.nodal_analysis.dev_tools_analyses.full_fe_reporting import (
    _185, _187, _186, _182,
    _188, _184, _183, _181
)
from mastapy._internal.python_net import python_net_import

_FE_SUBSTRUCTURE_WITH_SELECTION_COMPONENTS = python_net_import('SMT.MastaAPI.SystemModel.FE', 'FESubstructureWithSelectionComponents')


__docformat__ = 'restructuredtext en'
__all__ = ('FESubstructureWithSelectionComponents',)


class FESubstructureWithSelectionComponents(_2098.FESubstructureWithSelection):
    '''FESubstructureWithSelectionComponents

    This is a mastapy class.
    '''

    TYPE = _FE_SUBSTRUCTURE_WITH_SELECTION_COMPONENTS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'FESubstructureWithSelectionComponents.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def radius_of_circle_through_selected_nodes(self) -> 'float':
        '''float: 'RadiusOfCircleThroughSelectedNodes' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.RadiusOfCircleThroughSelectedNodes

    @property
    def manual_alignment(self) -> '_1280.CoordinateSystemEditor':
        '''CoordinateSystemEditor: 'ManualAlignment' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1280.CoordinateSystemEditor)(self.wrapped.ManualAlignment) if self.wrapped.ManualAlignment else None

    @property
    def distance_between_selected_nodes(self) -> 'Vector3D':
        '''Vector3D: 'DistanceBetweenSelectedNodes' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_vector3d(self.wrapped.DistanceBetweenSelectedNodes)
        return value

    @property
    def midpoint_of_selected_nodes(self) -> 'Vector3D':
        '''Vector3D: 'MidpointOfSelectedNodes' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_vector3d(self.wrapped.MidpointOfSelectedNodes)
        return value

    @property
    def centre_of_circle_through_selected_nodes(self) -> 'Vector3D':
        '''Vector3D: 'CentreOfCircleThroughSelectedNodes' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_vector3d(self.wrapped.CentreOfCircleThroughSelectedNodes)
        return value

    @property
    def component_links(self) -> 'List[_2128.FELinkWithSelection]':
        '''List[FELinkWithSelection]: 'ComponentLinks' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ComponentLinks, constructor.new(_2128.FELinkWithSelection))
        return value

    @property
    def links_for_selected_component(self) -> 'List[_2128.FELinkWithSelection]':
        '''List[FELinkWithSelection]: 'LinksForSelectedComponent' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.LinksForSelectedComponent, constructor.new(_2128.FELinkWithSelection))
        return value

    @property
    def links_for_electric_machine(self) -> 'List[_2128.FELinkWithSelection]':
        '''List[FELinkWithSelection]: 'LinksForElectricMachine' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.LinksForElectricMachine, constructor.new(_2128.FELinkWithSelection))
        return value

    @property
    def rigid_element_properties(self) -> 'List[_2085.ElementPropertiesWithSelection[_185.ElementPropertiesRigid]]':
        '''List[ElementPropertiesWithSelection[ElementPropertiesRigid]]: 'RigidElementProperties' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.RigidElementProperties, constructor.new(_2085.ElementPropertiesWithSelection)[_185.ElementPropertiesRigid])
        return value

    @property
    def solid_element_properties(self) -> 'List[_2085.ElementPropertiesWithSelection[_187.ElementPropertiesSolid]]':
        '''List[ElementPropertiesWithSelection[ElementPropertiesSolid]]: 'SolidElementProperties' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.SolidElementProperties, constructor.new(_2085.ElementPropertiesWithSelection)[_187.ElementPropertiesSolid])
        return value

    @property
    def shell_element_properties(self) -> 'List[_2085.ElementPropertiesWithSelection[_186.ElementPropertiesShell]]':
        '''List[ElementPropertiesWithSelection[ElementPropertiesShell]]: 'ShellElementProperties' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ShellElementProperties, constructor.new(_2085.ElementPropertiesWithSelection)[_186.ElementPropertiesShell])
        return value

    @property
    def beam_element_properties(self) -> 'List[_2085.ElementPropertiesWithSelection[_182.ElementPropertiesBeam]]':
        '''List[ElementPropertiesWithSelection[ElementPropertiesBeam]]: 'BeamElementProperties' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.BeamElementProperties, constructor.new(_2085.ElementPropertiesWithSelection)[_182.ElementPropertiesBeam])
        return value

    @property
    def spring_dashpot_element_properties(self) -> 'List[_2085.ElementPropertiesWithSelection[_188.ElementPropertiesSpringDashpot]]':
        '''List[ElementPropertiesWithSelection[ElementPropertiesSpringDashpot]]: 'SpringDashpotElementProperties' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.SpringDashpotElementProperties, constructor.new(_2085.ElementPropertiesWithSelection)[_188.ElementPropertiesSpringDashpot])
        return value

    @property
    def mass_element_properties(self) -> 'List[_2085.ElementPropertiesWithSelection[_184.ElementPropertiesMass]]':
        '''List[ElementPropertiesWithSelection[ElementPropertiesMass]]: 'MassElementProperties' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.MassElementProperties, constructor.new(_2085.ElementPropertiesWithSelection)[_184.ElementPropertiesMass])
        return value

    @property
    def interface_element_properties(self) -> 'List[_2085.ElementPropertiesWithSelection[_183.ElementPropertiesInterface]]':
        '''List[ElementPropertiesWithSelection[ElementPropertiesInterface]]: 'InterfaceElementProperties' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.InterfaceElementProperties, constructor.new(_2085.ElementPropertiesWithSelection)[_183.ElementPropertiesInterface])
        return value

    @property
    def other_element_properties(self) -> 'List[_2085.ElementPropertiesWithSelection[_181.ElementPropertiesBase]]':
        '''List[ElementPropertiesWithSelection[ElementPropertiesBase]]: 'OtherElementProperties' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.OtherElementProperties, constructor.new(_2085.ElementPropertiesWithSelection)[_181.ElementPropertiesBase])
        return value

    @property
    def materials(self) -> 'List[_2107.MaterialPropertiesWithSelection]':
        '''List[MaterialPropertiesWithSelection]: 'Materials' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Materials, constructor.new(_2107.MaterialPropertiesWithSelection))
        return value

    @property
    def coordinate_systems(self) -> 'List[_2077.CoordinateSystemWithSelection]':
        '''List[CoordinateSystemWithSelection]: 'CoordinateSystems' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.CoordinateSystems, constructor.new(_2077.CoordinateSystemWithSelection))
        return value

    @property
    def contact_pairs(self) -> 'List[_2076.ContactPairWithSelection]':
        '''List[ContactPairWithSelection]: 'ContactPairs' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ContactPairs, constructor.new(_2076.ContactPairWithSelection))
        return value

    def replace_selected_shaft(self):
        ''' 'ReplaceSelectedShaft' is the original name of this method.'''

        self.wrapped.ReplaceSelectedShaft()

    def auto_select_node_ring(self):
        ''' 'AutoSelectNodeRing' is the original name of this method.'''

        self.wrapped.AutoSelectNodeRing()

    def use_selected_component_for_alignment(self):
        ''' 'UseSelectedComponentForAlignment' is the original name of this method.'''

        self.wrapped.UseSelectedComponentForAlignment()



'''_332.py

RateableMesh
'''


from mastapy import _0
from mastapy._internal.python_net import python_net_import

_RATEABLE_MESH = python_net_import('SMT.MastaAPI.Gears.Rating', 'RateableMesh')


__docformat__ = 'restructuredtext en'
__all__ = ('RateableMesh',)


class RateableMesh(_0.APIBase):
    '''RateableMesh

    This is a mastapy class.
    '''

    TYPE = _RATEABLE_MESH

    __hash__ = None

    def __init__(self, instance_to_wrap: 'RateableMesh.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_69.py

LinearStiffnessProperties
'''


from mastapy._internal import constructor
from mastapy.nodal_analysis import _43
from mastapy._internal.python_net import python_net_import

_LINEAR_STIFFNESS_PROPERTIES = python_net_import('SMT.MastaAPI.NodalAnalysis', 'LinearStiffnessProperties')


__docformat__ = 'restructuredtext en'
__all__ = ('LinearStiffnessProperties',)


class LinearStiffnessProperties(_43.AbstractLinearConnectionProperties):
    '''LinearStiffnessProperties

    This is a mastapy class.
    '''

    TYPE = _LINEAR_STIFFNESS_PROPERTIES

    __hash__ = None

    def __init__(self, instance_to_wrap: 'LinearStiffnessProperties.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def torsional_stiffness(self) -> 'float':
        '''float: 'TorsionalStiffness' is the original name of this property.'''

        return self.wrapped.TorsionalStiffness

    @torsional_stiffness.setter
    def torsional_stiffness(self, value: 'float'):
        self.wrapped.TorsionalStiffness = float(value) if value else 0.0

    @property
    def radial_stiffness(self) -> 'float':
        '''float: 'RadialStiffness' is the original name of this property.'''

        return self.wrapped.RadialStiffness

    @radial_stiffness.setter
    def radial_stiffness(self, value: 'float'):
        self.wrapped.RadialStiffness = float(value) if value else 0.0

    @property
    def axial_stiffness(self) -> 'float':
        '''float: 'AxialStiffness' is the original name of this property.'''

        return self.wrapped.AxialStiffness

    @axial_stiffness.setter
    def axial_stiffness(self, value: 'float'):
        self.wrapped.AxialStiffness = float(value) if value else 0.0

    @property
    def tilt_stiffness(self) -> 'float':
        '''float: 'TiltStiffness' is the original name of this property.'''

        return self.wrapped.TiltStiffness

    @tilt_stiffness.setter
    def tilt_stiffness(self, value: 'float'):
        self.wrapped.TiltStiffness = float(value) if value else 0.0



'''_357.py

VirtualCylindricalGearSet
'''


from typing import List, Generic, TypeVar

from mastapy._internal import constructor, conversion
from mastapy import _0
from mastapy.gears.rating.virtual_cylindrical_gears import _354
from mastapy._internal.python_net import python_net_import

_VIRTUAL_CYLINDRICAL_GEAR_SET = python_net_import('SMT.MastaAPI.Gears.Rating.VirtualCylindricalGears', 'VirtualCylindricalGearSet')


__docformat__ = 'restructuredtext en'
__all__ = ('VirtualCylindricalGearSet',)


T = TypeVar('T', bound='_354.VirtualCylindricalGearBasic')


class VirtualCylindricalGearSet(_0.APIBase, Generic[T]):
    '''VirtualCylindricalGearSet

    This is a mastapy class.

    Generic Types:
        T
    '''

    TYPE = _VIRTUAL_CYLINDRICAL_GEAR_SET

    __hash__ = None

    def __init__(self, instance_to_wrap: 'VirtualCylindricalGearSet.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def virtual_centre_distance(self) -> 'float':
        '''float: 'VirtualCentreDistance' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.VirtualCentreDistance

    @property
    def transverse_contact_ratio_for_virtual_cylindrical_gears(self) -> 'float':
        '''float: 'TransverseContactRatioForVirtualCylindricalGears' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TransverseContactRatioForVirtualCylindricalGears

    @property
    def face_contact_ratio_transverse_for_virtual_cylindrical_gears(self) -> 'float':
        '''float: 'FaceContactRatioTransverseForVirtualCylindricalGears' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FaceContactRatioTransverseForVirtualCylindricalGears

    @property
    def virtual_contact_ratio_transverse_for_virtual_cylindrical_gears(self) -> 'float':
        '''float: 'VirtualContactRatioTransverseForVirtualCylindricalGears' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.VirtualContactRatioTransverseForVirtualCylindricalGears

    @property
    def transverse_contact_ratio_normal_for_virtual_cylindrical_gears(self) -> 'float':
        '''float: 'TransverseContactRatioNormalForVirtualCylindricalGears' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TransverseContactRatioNormalForVirtualCylindricalGears

    @property
    def effective_face_width_of_virtual_cylindrical_gears(self) -> 'float':
        '''float: 'EffectiveFaceWidthOfVirtualCylindricalGears' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.EffectiveFaceWidthOfVirtualCylindricalGears

    @property
    def face_width_of_virtual_cylindrical_gears(self) -> 'float':
        '''float: 'FaceWidthOfVirtualCylindricalGears' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FaceWidthOfVirtualCylindricalGears

    @property
    def virtual_pinion(self) -> 'T':
        '''T: 'VirtualPinion' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.VirtualPinion

    @property
    def virtual_wheel(self) -> 'T':
        '''T: 'VirtualWheel' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.VirtualWheel

    @property
    def virtual_cylindrical_gears(self) -> 'List[T]':
        '''List[T]: 'VirtualCylindricalGears' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.VirtualCylindricalGears)
        return value



'''_6562.py

ElectricMachineHarmonicLoadImportOptionsBase
'''


from mastapy import _0
from mastapy._internal.python_net import python_net_import

_ELECTRIC_MACHINE_HARMONIC_LOAD_IMPORT_OPTIONS_BASE = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.StaticLoads', 'ElectricMachineHarmonicLoadImportOptionsBase')


__docformat__ = 'restructuredtext en'
__all__ = ('ElectricMachineHarmonicLoadImportOptionsBase',)


class ElectricMachineHarmonicLoadImportOptionsBase(_0.APIBase):
    '''ElectricMachineHarmonicLoadImportOptionsBase

    This is a mastapy class.
    '''

    TYPE = _ELECTRIC_MACHINE_HARMONIC_LOAD_IMPORT_OPTIONS_BASE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ElectricMachineHarmonicLoadImportOptionsBase.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_7081.py

TransmissionErrorToOtherPowerLoad
'''


from mastapy._internal import constructor
from mastapy.math_utility import _1294
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_TRANSMISSION_ERROR_TO_OTHER_POWER_LOAD = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.AdvancedSystemDeflections', 'TransmissionErrorToOtherPowerLoad')


__docformat__ = 'restructuredtext en'
__all__ = ('TransmissionErrorToOtherPowerLoad',)


class TransmissionErrorToOtherPowerLoad(_0.APIBase):
    '''TransmissionErrorToOtherPowerLoad

    This is a mastapy class.
    '''

    TYPE = _TRANSMISSION_ERROR_TO_OTHER_POWER_LOAD

    __hash__ = None

    def __init__(self, instance_to_wrap: 'TransmissionErrorToOtherPowerLoad.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def mean_te(self) -> 'float':
        '''float: 'MeanTE' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MeanTE

    @property
    def peak_to_peak_te(self) -> 'float':
        '''float: 'PeakToPeakTE' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PeakToPeakTE

    @property
    def name(self) -> 'str':
        '''str: 'Name' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Name

    @property
    def fourier_series_of_te(self) -> '_1294.FourierSeries':
        '''FourierSeries: 'FourierSeriesOfTE' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1294.FourierSeries)(self.wrapped.FourierSeriesOfTE) if self.wrapped.FourierSeriesOfTE else None



'''_4377.py

StraightBevelDiffGearModalAnalysisAtAStiffness
'''


from mastapy.system_model.part_model.gears import _2252, _2256, _2257
from mastapy._internal import constructor
from mastapy._internal.cast_exception import CastException
from mastapy.system_model.analyses_and_results.static_loads import _6645, _6651, _6652
from mastapy.system_model.analyses_and_results.modal_analyses_at_a_stiffness import _4287
from mastapy._internal.python_net import python_net_import

_STRAIGHT_BEVEL_DIFF_GEAR_MODAL_ANALYSIS_AT_A_STIFFNESS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalysesAtAStiffness', 'StraightBevelDiffGearModalAnalysisAtAStiffness')


__docformat__ = 'restructuredtext en'
__all__ = ('StraightBevelDiffGearModalAnalysisAtAStiffness',)


class StraightBevelDiffGearModalAnalysisAtAStiffness(_4287.BevelGearModalAnalysisAtAStiffness):
    '''StraightBevelDiffGearModalAnalysisAtAStiffness

    This is a mastapy class.
    '''

    TYPE = _STRAIGHT_BEVEL_DIFF_GEAR_MODAL_ANALYSIS_AT_A_STIFFNESS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'StraightBevelDiffGearModalAnalysisAtAStiffness.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2252.StraightBevelDiffGear':
        '''StraightBevelDiffGear: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2252.StraightBevelDiffGear.TYPE not in self.wrapped.ComponentDesign.__class__.__mro__:
            raise CastException('Failed to cast component_design to StraightBevelDiffGear. Expected: {}.'.format(self.wrapped.ComponentDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ComponentDesign.__class__)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_load_case(self) -> '_6645.StraightBevelDiffGearLoadCase':
        '''StraightBevelDiffGearLoadCase: 'ComponentLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _6645.StraightBevelDiffGearLoadCase.TYPE not in self.wrapped.ComponentLoadCase.__class__.__mro__:
            raise CastException('Failed to cast component_load_case to StraightBevelDiffGearLoadCase. Expected: {}.'.format(self.wrapped.ComponentLoadCase.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ComponentLoadCase.__class__)(self.wrapped.ComponentLoadCase) if self.wrapped.ComponentLoadCase else None



'''_5241.py

BoltedJointCompoundMultibodyDynamicsAnalysis
'''


from typing import List

from mastapy.system_model.part_model import _2152
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.mbd_analyses import _5090
from mastapy.system_model.analyses_and_results.mbd_analyses.compound import _5319
from mastapy._internal.python_net import python_net_import

_BOLTED_JOINT_COMPOUND_MULTIBODY_DYNAMICS_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses.Compound', 'BoltedJointCompoundMultibodyDynamicsAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('BoltedJointCompoundMultibodyDynamicsAnalysis',)


class BoltedJointCompoundMultibodyDynamicsAnalysis(_5319.SpecialisedAssemblyCompoundMultibodyDynamicsAnalysis):
    '''BoltedJointCompoundMultibodyDynamicsAnalysis

    This is a mastapy class.
    '''

    TYPE = _BOLTED_JOINT_COMPOUND_MULTIBODY_DYNAMICS_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'BoltedJointCompoundMultibodyDynamicsAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2152.BoltedJoint':
        '''BoltedJoint: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2152.BoltedJoint)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def assembly_design(self) -> '_2152.BoltedJoint':
        '''BoltedJoint: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2152.BoltedJoint)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_analysis_cases_ready(self) -> 'List[_5090.BoltedJointMultibodyDynamicsAnalysis]':
        '''List[BoltedJointMultibodyDynamicsAnalysis]: 'AssemblyAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCasesReady, constructor.new(_5090.BoltedJointMultibodyDynamicsAnalysis))
        return value

    @property
    def assembly_analysis_cases(self) -> 'List[_5090.BoltedJointMultibodyDynamicsAnalysis]':
        '''List[BoltedJointMultibodyDynamicsAnalysis]: 'AssemblyAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCases, constructor.new(_5090.BoltedJointMultibodyDynamicsAnalysis))
        return value



'''_1313.py

TransformMatrix3D
'''


from typing import Optional

from mastapy._internal import constructor, conversion
from mastapy._math.vector_3d import Vector3D
from mastapy._math.matrix_4x4 import Matrix4x4
from mastapy._internal.tuple_with_name import TupleWithName
from mastapy.math_utility import _1305
from mastapy._internal.python_net import python_net_import

_TRANSFORM_MATRIX_3D = python_net_import('SMT.MastaAPI.MathUtility', 'TransformMatrix3D')


__docformat__ = 'restructuredtext en'
__all__ = ('TransformMatrix3D',)


class TransformMatrix3D(_1305.RealMatrix):
    '''TransformMatrix3D

    This is a mastapy class.
    '''

    TYPE = _TRANSFORM_MATRIX_3D

    __hash__ = None

    def __init__(self, instance_to_wrap: 'TransformMatrix3D.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def is_identity(self) -> 'bool':
        '''bool: 'IsIdentity' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.IsIdentity

    @property
    def x_axis(self) -> 'Vector3D':
        '''Vector3D: 'XAxis' is the original name of this property.'''

        value = conversion.pn_to_mp_vector3d(self.wrapped.XAxis)
        return value

    @x_axis.setter
    def x_axis(self, value: 'Vector3D'):
        value = value if value else None
        value = conversion.mp_to_pn_vector3d(value)
        self.wrapped.XAxis = value

    @property
    def y_axis(self) -> 'Vector3D':
        '''Vector3D: 'YAxis' is the original name of this property.'''

        value = conversion.pn_to_mp_vector3d(self.wrapped.YAxis)
        return value

    @y_axis.setter
    def y_axis(self, value: 'Vector3D'):
        value = value if value else None
        value = conversion.mp_to_pn_vector3d(value)
        self.wrapped.YAxis = value

    @property
    def z_axis(self) -> 'Vector3D':
        '''Vector3D: 'ZAxis' is the original name of this property.'''

        value = conversion.pn_to_mp_vector3d(self.wrapped.ZAxis)
        return value

    @z_axis.setter
    def z_axis(self, value: 'Vector3D'):
        value = value if value else None
        value = conversion.mp_to_pn_vector3d(value)
        self.wrapped.ZAxis = value

    @property
    def translation(self) -> 'Vector3D':
        '''Vector3D: 'Translation' is the original name of this property.'''

        value = conversion.pn_to_mp_vector3d(self.wrapped.Translation)
        return value

    @translation.setter
    def translation(self, value: 'Vector3D'):
        value = value if value else None
        value = conversion.mp_to_pn_vector3d(value)
        self.wrapped.Translation = value

    def transposed(self) -> 'Matrix4x4':
        ''' 'Transposed' is the original name of this method.

        Returns:
            Matrix4x4
        '''

        return conversion.pn_to_mp_matrix4x4(self.wrapped.Transposed())

    def rigid_inverse(self) -> 'Matrix4x4':
        ''' 'RigidInverse' is the original name of this method.

        Returns:
            Matrix4x4
        '''

        return conversion.pn_to_mp_matrix4x4(self.wrapped.RigidInverse())

    def has_rotation(self, tolerance: Optional['float'] = 0.0) -> 'bool':
        ''' 'HasRotation' is the original name of this method.

        Args:
            tolerance (float, optional)

        Returns:
            bool
        '''

        tolerance = float(tolerance)
        method_result = self.wrapped.HasRotation(tolerance if tolerance else 0.0)
        return method_result

    def has_translation(self, tolerance: Optional['float'] = 0.0) -> 'bool':
        ''' 'HasTranslation' is the original name of this method.

        Args:
            tolerance (float, optional)

        Returns:
            bool
        '''

        tolerance = float(tolerance)
        method_result = self.wrapped.HasTranslation(tolerance if tolerance else 0.0)
        return method_result

    def negated(self) -> 'Matrix4x4':
        ''' 'Negated' is the original name of this method.

        Returns:
            Matrix4x4
        '''

        return conversion.pn_to_mp_matrix4x4(self.wrapped.Negated())

    def transform_linear_and_angular_components(self, linear: 'Vector3D', angular: 'Vector3D') -> 'TupleWithName':
        ''' 'TransformLinearAndAngularComponents' is the original name of this method.

        Args:
            linear (Vector3D)
            angular (Vector3D)

        Returns:
            TupleWithName
        '''

        linear = conversion.mp_to_pn_vector3d(linear)
        angular = conversion.mp_to_pn_vector3d(angular)
        return conversion.pn_to_mp_tuple_with_name(self.wrapped.TransformLinearAndAngularComponents(linear, angular), (conversion.pn_to_mp_vector3d, conversion.pn_to_mp_vector3d))

    def rotate(self, angular: 'Vector3D') -> 'Vector3D':
        ''' 'Rotate' is the original name of this method.

        Args:
            angular (Vector3D)

        Returns:
            Vector3D
        '''

        angular = conversion.mp_to_pn_vector3d(angular)
        return conversion.pn_to_mp_vector3d(self.wrapped.Rotate(angular))

    def transform(self, linear: 'Vector3D') -> 'Vector3D':
        ''' 'Transform' is the original name of this method.

        Args:
            linear (Vector3D)

        Returns:
            Vector3D
        '''

        linear = conversion.mp_to_pn_vector3d(linear)
        return conversion.pn_to_mp_vector3d(self.wrapped.Transform(linear))



'''_1324.py

OptimisationHistory
'''


from typing import List

from mastapy.math_utility.optimisation import _1326
from mastapy._internal import constructor, conversion
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_OPTIMISATION_HISTORY = python_net_import('SMT.MastaAPI.MathUtility.Optimisation', 'OptimisationHistory')


__docformat__ = 'restructuredtext en'
__all__ = ('OptimisationHistory',)


class OptimisationHistory(_0.APIBase):
    '''OptimisationHistory

    This is a mastapy class.
    '''

    TYPE = _OPTIMISATION_HISTORY

    __hash__ = None

    def __init__(self, instance_to_wrap: 'OptimisationHistory.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def input_history(self) -> 'List[_1326.OptimizationVariable]':
        '''List[OptimizationVariable]: 'InputHistory' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.InputHistory, constructor.new(_1326.OptimizationVariable))
        return value

    @property
    def target_history(self) -> 'List[_1326.OptimizationVariable]':
        '''List[OptimizationVariable]: 'TargetHistory' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.TargetHistory, constructor.new(_1326.OptimizationVariable))
        return value

    @property
    def input_names(self) -> 'List[str]':
        '''List[str]: 'InputNames' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.InputNames, str)
        return value

    @property
    def target_names(self) -> 'List[str]':
        '''List[str]: 'TargetNames' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.TargetNames, str)
        return value

    def add_input_history(self, value: '_1326.OptimizationVariable'):
        ''' 'AddInputHistory' is the original name of this method.

        Args:
            value (mastapy.math_utility.optimisation.OptimizationVariable)
        '''

        self.wrapped.AddInputHistory(value.wrapped if value else None)

    def add_target_history(self, value: '_1326.OptimizationVariable'):
        ''' 'AddTargetHistory' is the original name of this method.

        Args:
            value (mastapy.math_utility.optimisation.OptimizationVariable)
        '''

        self.wrapped.AddTargetHistory(value.wrapped if value else None)



'''_7063.py

SpringDamperConnectionAdvancedSystemDeflection
'''


from typing import List

from mastapy.system_model.connections_and_sockets.couplings import _2059
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.static_loads import _6642
from mastapy.system_model.analyses_and_results.system_deflections import _2512
from mastapy.system_model.analyses_and_results.advanced_system_deflections import _6996
from mastapy._internal.python_net import python_net_import

_SPRING_DAMPER_CONNECTION_ADVANCED_SYSTEM_DEFLECTION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.AdvancedSystemDeflections', 'SpringDamperConnectionAdvancedSystemDeflection')


__docformat__ = 'restructuredtext en'
__all__ = ('SpringDamperConnectionAdvancedSystemDeflection',)


class SpringDamperConnectionAdvancedSystemDeflection(_6996.CouplingConnectionAdvancedSystemDeflection):
    '''SpringDamperConnectionAdvancedSystemDeflection

    This is a mastapy class.
    '''

    TYPE = _SPRING_DAMPER_CONNECTION_ADVANCED_SYSTEM_DEFLECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'SpringDamperConnectionAdvancedSystemDeflection.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def connection_design(self) -> '_2059.SpringDamperConnection':
        '''SpringDamperConnection: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2059.SpringDamperConnection)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_load_case(self) -> '_6642.SpringDamperConnectionLoadCase':
        '''SpringDamperConnectionLoadCase: 'ConnectionLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6642.SpringDamperConnectionLoadCase)(self.wrapped.ConnectionLoadCase) if self.wrapped.ConnectionLoadCase else None

    @property
    def connection_system_deflection_results(self) -> 'List[_2512.SpringDamperConnectionSystemDeflection]':
        '''List[SpringDamperConnectionSystemDeflection]: 'ConnectionSystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ConnectionSystemDeflectionResults, constructor.new(_2512.SpringDamperConnectionSystemDeflection))
        return value



'''_3015.py

KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponseAtASpeed
'''


from mastapy.system_model.part_model.gears import _2245
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.static_loads import _6599
from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed import _3012
from mastapy._internal.python_net import python_net_import

_KLINGELNBERG_CYCLO_PALLOID_HYPOID_GEAR_STEADY_STATE_SYNCHRONOUS_RESPONSE_AT_A_SPEED = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SteadyStateSynchronousResponsesAtASpeed', 'KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponseAtASpeed')


__docformat__ = 'restructuredtext en'
__all__ = ('KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponseAtASpeed',)


class KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponseAtASpeed(_3012.KlingelnbergCycloPalloidConicalGearSteadyStateSynchronousResponseAtASpeed):
    '''KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponseAtASpeed

    This is a mastapy class.
    '''

    TYPE = _KLINGELNBERG_CYCLO_PALLOID_HYPOID_GEAR_STEADY_STATE_SYNCHRONOUS_RESPONSE_AT_A_SPEED

    __hash__ = None

    def __init__(self, instance_to_wrap: 'KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponseAtASpeed.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2245.KlingelnbergCycloPalloidHypoidGear':
        '''KlingelnbergCycloPalloidHypoidGear: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2245.KlingelnbergCycloPalloidHypoidGear)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_load_case(self) -> '_6599.KlingelnbergCycloPalloidHypoidGearLoadCase':
        '''KlingelnbergCycloPalloidHypoidGearLoadCase: 'ComponentLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6599.KlingelnbergCycloPalloidHypoidGearLoadCase)(self.wrapped.ComponentLoadCase) if self.wrapped.ComponentLoadCase else None



'''_4049.py

DutyCycleResultsForAllGearSets
'''


from mastapy.gears.analysis import _1153
from mastapy._internal import constructor
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_DUTY_CYCLE_RESULTS_FOR_ALL_GEAR_SETS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ParametricStudyTools', 'DutyCycleResultsForAllGearSets')


__docformat__ = 'restructuredtext en'
__all__ = ('DutyCycleResultsForAllGearSets',)


class DutyCycleResultsForAllGearSets(_0.APIBase):
    '''DutyCycleResultsForAllGearSets

    This is a mastapy class.
    '''

    TYPE = _DUTY_CYCLE_RESULTS_FOR_ALL_GEAR_SETS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'DutyCycleResultsForAllGearSets.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def duty_cycle_results(self) -> '_1153.GearSetGroupDutyCycle':
        '''GearSetGroupDutyCycle: 'DutyCycleResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1153.GearSetGroupDutyCycle)(self.wrapped.DutyCycleResults) if self.wrapped.DutyCycleResults else None



'''_2495.py

PulleySystemDeflection
'''


from mastapy.system_model.part_model.couplings import _2297, _2294
from mastapy._internal import constructor
from mastapy._internal.cast_exception import CastException
from mastapy.system_model.analyses_and_results.static_loads import _6625, _6537
from mastapy.system_model.analyses_and_results.power_flows import _3823, _3774
from mastapy.system_model.analyses_and_results.system_deflections import _2432
from mastapy._internal.python_net import python_net_import

_PULLEY_SYSTEM_DEFLECTION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SystemDeflections', 'PulleySystemDeflection')


__docformat__ = 'restructuredtext en'
__all__ = ('PulleySystemDeflection',)


class PulleySystemDeflection(_2432.CouplingHalfSystemDeflection):
    '''PulleySystemDeflection

    This is a mastapy class.
    '''

    TYPE = _PULLEY_SYSTEM_DEFLECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'PulleySystemDeflection.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2297.Pulley':
        '''Pulley: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2297.Pulley.TYPE not in self.wrapped.ComponentDesign.__class__.__mro__:
            raise CastException('Failed to cast component_design to Pulley. Expected: {}.'.format(self.wrapped.ComponentDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ComponentDesign.__class__)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_load_case(self) -> '_6625.PulleyLoadCase':
        '''PulleyLoadCase: 'ComponentLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _6625.PulleyLoadCase.TYPE not in self.wrapped.ComponentLoadCase.__class__.__mro__:
            raise CastException('Failed to cast component_load_case to PulleyLoadCase. Expected: {}.'.format(self.wrapped.ComponentLoadCase.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ComponentLoadCase.__class__)(self.wrapped.ComponentLoadCase) if self.wrapped.ComponentLoadCase else None

    @property
    def power_flow_results(self) -> '_3823.PulleyPowerFlow':
        '''PulleyPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _3823.PulleyPowerFlow.TYPE not in self.wrapped.PowerFlowResults.__class__.__mro__:
            raise CastException('Failed to cast power_flow_results to PulleyPowerFlow. Expected: {}.'.format(self.wrapped.PowerFlowResults.__class__.__qualname__))

        return constructor.new_override(self.wrapped.PowerFlowResults.__class__)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None



'''_3130.py

FEPartCompoundSteadyStateSynchronousResponseAtASpeed
'''


from typing import List

from mastapy.system_model.part_model import _2161
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed import _3000
from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed.compound import _3076
from mastapy._internal.python_net import python_net_import

_FE_PART_COMPOUND_STEADY_STATE_SYNCHRONOUS_RESPONSE_AT_A_SPEED = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SteadyStateSynchronousResponsesAtASpeed.Compound', 'FEPartCompoundSteadyStateSynchronousResponseAtASpeed')


__docformat__ = 'restructuredtext en'
__all__ = ('FEPartCompoundSteadyStateSynchronousResponseAtASpeed',)


class FEPartCompoundSteadyStateSynchronousResponseAtASpeed(_3076.AbstractShaftOrHousingCompoundSteadyStateSynchronousResponseAtASpeed):
    '''FEPartCompoundSteadyStateSynchronousResponseAtASpeed

    This is a mastapy class.
    '''

    TYPE = _FE_PART_COMPOUND_STEADY_STATE_SYNCHRONOUS_RESPONSE_AT_A_SPEED

    __hash__ = None

    def __init__(self, instance_to_wrap: 'FEPartCompoundSteadyStateSynchronousResponseAtASpeed.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2161.FEPart':
        '''FEPart: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2161.FEPart)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_analysis_cases_ready(self) -> 'List[_3000.FEPartSteadyStateSynchronousResponseAtASpeed]':
        '''List[FEPartSteadyStateSynchronousResponseAtASpeed]: 'ComponentAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ComponentAnalysisCasesReady, constructor.new(_3000.FEPartSteadyStateSynchronousResponseAtASpeed))
        return value

    @property
    def planetaries(self) -> 'List[FEPartCompoundSteadyStateSynchronousResponseAtASpeed]':
        '''List[FEPartCompoundSteadyStateSynchronousResponseAtASpeed]: 'Planetaries' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Planetaries, constructor.new(FEPartCompoundSteadyStateSynchronousResponseAtASpeed))
        return value

    @property
    def component_analysis_cases(self) -> 'List[_3000.FEPartSteadyStateSynchronousResponseAtASpeed]':
        '''List[FEPartSteadyStateSynchronousResponseAtASpeed]: 'ComponentAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ComponentAnalysisCases, constructor.new(_3000.FEPartSteadyStateSynchronousResponseAtASpeed))
        return value



'''_5330.py

StraightBevelGearMeshCompoundMultibodyDynamicsAnalysis
'''


from typing import List

from mastapy.system_model.connections_and_sockets.gears import _2036
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.mbd_analyses import _5191
from mastapy.system_model.analyses_and_results.mbd_analyses.compound import _5238
from mastapy._internal.python_net import python_net_import

_STRAIGHT_BEVEL_GEAR_MESH_COMPOUND_MULTIBODY_DYNAMICS_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses.Compound', 'StraightBevelGearMeshCompoundMultibodyDynamicsAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('StraightBevelGearMeshCompoundMultibodyDynamicsAnalysis',)


class StraightBevelGearMeshCompoundMultibodyDynamicsAnalysis(_5238.BevelGearMeshCompoundMultibodyDynamicsAnalysis):
    '''StraightBevelGearMeshCompoundMultibodyDynamicsAnalysis

    This is a mastapy class.
    '''

    TYPE = _STRAIGHT_BEVEL_GEAR_MESH_COMPOUND_MULTIBODY_DYNAMICS_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'StraightBevelGearMeshCompoundMultibodyDynamicsAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2036.StraightBevelGearMesh':
        '''StraightBevelGearMesh: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2036.StraightBevelGearMesh)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def connection_design(self) -> '_2036.StraightBevelGearMesh':
        '''StraightBevelGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2036.StraightBevelGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_analysis_cases_ready(self) -> 'List[_5191.StraightBevelGearMeshMultibodyDynamicsAnalysis]':
        '''List[StraightBevelGearMeshMultibodyDynamicsAnalysis]: 'ConnectionAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ConnectionAnalysisCasesReady, constructor.new(_5191.StraightBevelGearMeshMultibodyDynamicsAnalysis))
        return value

    @property
    def connection_analysis_cases(self) -> 'List[_5191.StraightBevelGearMeshMultibodyDynamicsAnalysis]':
        '''List[StraightBevelGearMeshMultibodyDynamicsAnalysis]: 'ConnectionAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ConnectionAnalysisCases, constructor.new(_5191.StraightBevelGearMeshMultibodyDynamicsAnalysis))
        return value



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._2815 import AbstractAssemblyCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2816 import AbstractShaftCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2817 import AbstractShaftOrHousingCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2818 import AbstractShaftToMountableComponentConnectionCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2819 import AGMAGleasonConicalGearCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2820 import AGMAGleasonConicalGearMeshCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2821 import AGMAGleasonConicalGearSetCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2822 import AssemblyCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2823 import BearingCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2824 import BeltConnectionCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2825 import BeltDriveCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2826 import BevelDifferentialGearCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2827 import BevelDifferentialGearMeshCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2828 import BevelDifferentialGearSetCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2829 import BevelDifferentialPlanetGearCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2830 import BevelDifferentialSunGearCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2831 import BevelGearCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2832 import BevelGearMeshCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2833 import BevelGearSetCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2834 import BoltCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2835 import BoltedJointCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2836 import ClutchCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2837 import ClutchConnectionCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2838 import ClutchHalfCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2839 import CoaxialConnectionCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2840 import ComponentCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2841 import ConceptCouplingCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2842 import ConceptCouplingConnectionCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2843 import ConceptCouplingHalfCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2844 import ConceptGearCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2845 import ConceptGearMeshCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2846 import ConceptGearSetCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2847 import ConicalGearCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2848 import ConicalGearMeshCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2849 import ConicalGearSetCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2850 import ConnectionCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2851 import ConnectorCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2852 import CouplingCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2853 import CouplingConnectionCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2854 import CouplingHalfCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2855 import CVTBeltConnectionCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2856 import CVTCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2857 import CVTPulleyCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2858 import CycloidalAssemblyCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2859 import CycloidalDiscCentralBearingConnectionCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2860 import CycloidalDiscCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2861 import CycloidalDiscPlanetaryBearingConnectionCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2862 import CylindricalGearCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2863 import CylindricalGearMeshCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2864 import CylindricalGearSetCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2865 import CylindricalPlanetGearCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2866 import DatumCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2867 import ExternalCADModelCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2868 import FaceGearCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2869 import FaceGearMeshCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2870 import FaceGearSetCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2871 import FEPartCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2872 import FlexiblePinAssemblyCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2873 import GearCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2874 import GearMeshCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2875 import GearSetCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2876 import GuideDxfModelCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2877 import HypoidGearCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2878 import HypoidGearMeshCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2879 import HypoidGearSetCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2880 import InterMountableComponentConnectionCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2881 import KlingelnbergCycloPalloidConicalGearCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2882 import KlingelnbergCycloPalloidConicalGearMeshCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2883 import KlingelnbergCycloPalloidConicalGearSetCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2884 import KlingelnbergCycloPalloidHypoidGearCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2885 import KlingelnbergCycloPalloidHypoidGearMeshCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2886 import KlingelnbergCycloPalloidHypoidGearSetCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2887 import KlingelnbergCycloPalloidSpiralBevelGearCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2888 import KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2889 import KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2890 import MassDiscCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2891 import MeasurementComponentCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2892 import MountableComponentCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2893 import OilSealCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2894 import PartCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2895 import PartToPartShearCouplingCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2896 import PartToPartShearCouplingConnectionCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2897 import PartToPartShearCouplingHalfCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2898 import PlanetaryConnectionCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2899 import PlanetaryGearSetCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2900 import PlanetCarrierCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2901 import PointLoadCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2902 import PowerLoadCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2903 import PulleyCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2904 import RingPinsCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2905 import RingPinsToDiscConnectionCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2906 import RollingRingAssemblyCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2907 import RollingRingCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2908 import RollingRingConnectionCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2909 import RootAssemblyCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2910 import ShaftCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2911 import ShaftHubConnectionCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2912 import ShaftToMountableComponentConnectionCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2913 import SpecialisedAssemblyCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2914 import SpiralBevelGearCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2915 import SpiralBevelGearMeshCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2916 import SpiralBevelGearSetCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2917 import SpringDamperCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2918 import SpringDamperConnectionCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2919 import SpringDamperHalfCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2920 import StraightBevelDiffGearCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2921 import StraightBevelDiffGearMeshCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2922 import StraightBevelDiffGearSetCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2923 import StraightBevelGearCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2924 import StraightBevelGearMeshCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2925 import StraightBevelGearSetCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2926 import StraightBevelPlanetGearCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2927 import StraightBevelSunGearCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2928 import SynchroniserCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2929 import SynchroniserHalfCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2930 import SynchroniserPartCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2931 import SynchroniserSleeveCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2932 import TorqueConverterCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2933 import TorqueConverterConnectionCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2934 import TorqueConverterPumpCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2935 import TorqueConverterTurbineCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2936 import UnbalancedMassCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2937 import VirtualComponentCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2938 import WormGearCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2939 import WormGearMeshCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2940 import WormGearSetCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2941 import ZerolBevelGearCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2942 import ZerolBevelGearMeshCompoundSteadyStateSynchronousResponseOnAShaft
    from ._2943 import ZerolBevelGearSetCompoundSteadyStateSynchronousResponseOnAShaft



'''_4879.py

PointLoadModalAnalysis
'''


from mastapy.system_model.part_model import _2179
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.static_loads import _6623
from mastapy.system_model.analyses_and_results.system_deflections import _2493
from mastapy.system_model.analyses_and_results.modal_analyses import _4916
from mastapy._internal.python_net import python_net_import

_POINT_LOAD_MODAL_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalyses', 'PointLoadModalAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('PointLoadModalAnalysis',)


class PointLoadModalAnalysis(_4916.VirtualComponentModalAnalysis):
    '''PointLoadModalAnalysis

    This is a mastapy class.
    '''

    TYPE = _POINT_LOAD_MODAL_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'PointLoadModalAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2179.PointLoad':
        '''PointLoad: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2179.PointLoad)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_load_case(self) -> '_6623.PointLoadLoadCase':
        '''PointLoadLoadCase: 'ComponentLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6623.PointLoadLoadCase)(self.wrapped.ComponentLoadCase) if self.wrapped.ComponentLoadCase else None

    @property
    def system_deflection_results(self) -> '_2493.PointLoadSystemDeflection':
        '''PointLoadSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2493.PointLoadSystemDeflection)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None



'''_5775.py

TorqueConverterHarmonicAnalysis
'''


from mastapy.system_model.part_model.couplings import _2314
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.static_loads import _6659
from mastapy.system_model.analyses_and_results.system_deflections import _2532
from mastapy.system_model.analyses_and_results.harmonic_analyses import _5670
from mastapy._internal.python_net import python_net_import

_TORQUE_CONVERTER_HARMONIC_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.HarmonicAnalyses', 'TorqueConverterHarmonicAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('TorqueConverterHarmonicAnalysis',)


class TorqueConverterHarmonicAnalysis(_5670.CouplingHarmonicAnalysis):
    '''TorqueConverterHarmonicAnalysis

    This is a mastapy class.
    '''

    TYPE = _TORQUE_CONVERTER_HARMONIC_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'TorqueConverterHarmonicAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def assembly_design(self) -> '_2314.TorqueConverter':
        '''TorqueConverter: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2314.TorqueConverter)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_load_case(self) -> '_6659.TorqueConverterLoadCase':
        '''TorqueConverterLoadCase: 'AssemblyLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6659.TorqueConverterLoadCase)(self.wrapped.AssemblyLoadCase) if self.wrapped.AssemblyLoadCase else None

    @property
    def system_deflection_results(self) -> '_2532.TorqueConverterSystemDeflection':
        '''TorqueConverterSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2532.TorqueConverterSystemDeflection)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None



'''_718.py

ShavingDynamicsCalculation
'''


from typing import List, Generic, TypeVar

from mastapy._internal.implicit import overridable, list_with_selected_item
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy._internal import constructor, conversion
from mastapy.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics import _714, _713, _717
from mastapy.gears.manufacturing.cylindrical.cutter_simulation import _656
from mastapy.gears.manufacturing.cylindrical.cutters import _685, _680
from mastapy._internal.cast_exception import CastException
from mastapy.gears.gear_designs.cylindrical import _962
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_SHAVING_DYNAMICS_CALCULATION = python_net_import('SMT.MastaAPI.Gears.Manufacturing.Cylindrical.AxialAndPlungeShavingDynamics', 'ShavingDynamicsCalculation')


__docformat__ = 'restructuredtext en'
__all__ = ('ShavingDynamicsCalculation',)


T = TypeVar('T', bound='_717.ShavingDynamics')


class ShavingDynamicsCalculation(_0.APIBase, Generic[T]):
    '''ShavingDynamicsCalculation

    This is a mastapy class.

    Generic Types:
        T
    '''

    TYPE = _SHAVING_DYNAMICS_CALCULATION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ShavingDynamicsCalculation.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def life_cutter_tip_diameter(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'LifeCutterTipDiameter' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.LifeCutterTipDiameter) if self.wrapped.LifeCutterTipDiameter else None

    @life_cutter_tip_diameter.setter
    def life_cutter_tip_diameter(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0, is_overridden)
        self.wrapped.LifeCutterTipDiameter = value

    @property
    def new_cutter_tip_diameter(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'NewCutterTipDiameter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(overridable.Overridable_float)(self.wrapped.NewCutterTipDiameter) if self.wrapped.NewCutterTipDiameter else None

    @property
    def selected_redressing(self) -> 'list_with_selected_item.ListWithSelectedItem_T':
        '''list_with_selected_item.ListWithSelectedItem_T: 'SelectedRedressing' is the original name of this property.'''

        return constructor.new(list_with_selected_item.ListWithSelectedItem_T)(self.wrapped.SelectedRedressing) if self.wrapped.SelectedRedressing else None

    @selected_redressing.setter
    def selected_redressing(self, value: 'list_with_selected_item.ListWithSelectedItem_T.implicit_type()'):
        wrapper_type = list_with_selected_item.ListWithSelectedItem_T.wrapper_type()
        enclosed_type = list_with_selected_item.ListWithSelectedItem_T.implicit_type()
        value = wrapper_type[enclosed_type](value.wrapped if value else None)
        self.wrapped.SelectedRedressing = value

    @property
    def normal_tooth_thickness_reduction_between_redressings(self) -> 'float':
        '''float: 'NormalToothThicknessReductionBetweenRedressings' is the original name of this property.'''

        return self.wrapped.NormalToothThicknessReductionBetweenRedressings

    @normal_tooth_thickness_reduction_between_redressings.setter
    def normal_tooth_thickness_reduction_between_redressings(self, value: 'float'):
        self.wrapped.NormalToothThicknessReductionBetweenRedressings = float(value) if value else 0.0

    @property
    def life_cutter_normal_thickness(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'LifeCutterNormalThickness' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.LifeCutterNormalThickness) if self.wrapped.LifeCutterNormalThickness else None

    @life_cutter_normal_thickness.setter
    def life_cutter_normal_thickness(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0, is_overridden)
        self.wrapped.LifeCutterNormalThickness = value

    @property
    def adjusted_tip_diameter(self) -> 'List[float]':
        '''List[float]: 'AdjustedTipDiameter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_list_float(self.wrapped.AdjustedTipDiameter)
        return value

    @property
    def accuracy_level_iso6(self) -> '_714.RollAngleRangeRelativeToAccuracy':
        '''RollAngleRangeRelativeToAccuracy: 'AccuracyLevelISO6' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_714.RollAngleRangeRelativeToAccuracy)(self.wrapped.AccuracyLevelISO6) if self.wrapped.AccuracyLevelISO6 else None

    @property
    def accuracy_level_iso7(self) -> '_714.RollAngleRangeRelativeToAccuracy':
        '''RollAngleRangeRelativeToAccuracy: 'AccuracyLevelISO7' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_714.RollAngleRangeRelativeToAccuracy)(self.wrapped.AccuracyLevelISO7) if self.wrapped.AccuracyLevelISO7 else None

    @property
    def designed_gear(self) -> '_656.CylindricalCutterSimulatableGear':
        '''CylindricalCutterSimulatableGear: 'DesignedGear' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_656.CylindricalCutterSimulatableGear)(self.wrapped.DesignedGear) if self.wrapped.DesignedGear else None

    @property
    def shaver(self) -> '_685.CylindricalGearShaver':
        '''CylindricalGearShaver: 'Shaver' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _685.CylindricalGearShaver.TYPE not in self.wrapped.Shaver.__class__.__mro__:
            raise CastException('Failed to cast shaver to CylindricalGearShaver. Expected: {}.'.format(self.wrapped.Shaver.__class__.__qualname__))

        return constructor.new_override(self.wrapped.Shaver.__class__)(self.wrapped.Shaver) if self.wrapped.Shaver else None

    @property
    def life_shaver(self) -> '_685.CylindricalGearShaver':
        '''CylindricalGearShaver: 'LifeShaver' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _685.CylindricalGearShaver.TYPE not in self.wrapped.LifeShaver.__class__.__mro__:
            raise CastException('Failed to cast life_shaver to CylindricalGearShaver. Expected: {}.'.format(self.wrapped.LifeShaver.__class__.__qualname__))

        return constructor.new_override(self.wrapped.LifeShaver.__class__)(self.wrapped.LifeShaver) if self.wrapped.LifeShaver else None

    @property
    def new_cutter_start_of_shaving(self) -> '_962.CylindricalGearProfileMeasurement':
        '''CylindricalGearProfileMeasurement: 'NewCutterStartOfShaving' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_962.CylindricalGearProfileMeasurement)(self.wrapped.NewCutterStartOfShaving) if self.wrapped.NewCutterStartOfShaving else None

    @property
    def life_cutter_start_of_shaving(self) -> '_962.CylindricalGearProfileMeasurement':
        '''CylindricalGearProfileMeasurement: 'LifeCutterStartOfShaving' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_962.CylindricalGearProfileMeasurement)(self.wrapped.LifeCutterStartOfShaving) if self.wrapped.LifeCutterStartOfShaving else None

    @property
    def redressing_settings(self) -> 'List[_713.RedressingSettings[T]]':
        '''List[RedressingSettings[T]]: 'RedressingSettings' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.RedressingSettings, constructor.new(_713.RedressingSettings)[T])
        return value

    @property
    def report_names(self) -> 'List[str]':
        '''List[str]: 'ReportNames' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ReportNames, str)
        return value

    def cutter_simulation_calculation_required(self):
        ''' 'CutterSimulationCalculationRequired' is the original name of this method.'''

        self.wrapped.CutterSimulationCalculationRequired()

    def output_default_report_to(self, file_path: 'str'):
        ''' 'OutputDefaultReportTo' is the original name of this method.

        Args:
            file_path (str)
        '''

        file_path = str(file_path)
        self.wrapped.OutputDefaultReportTo(file_path if file_path else None)

    def get_default_report_with_encoded_images(self) -> 'str':
        ''' 'GetDefaultReportWithEncodedImages' is the original name of this method.

        Returns:
            str
        '''

        method_result = self.wrapped.GetDefaultReportWithEncodedImages()
        return method_result

    def output_active_report_to(self, file_path: 'str'):
        ''' 'OutputActiveReportTo' is the original name of this method.

        Args:
            file_path (str)
        '''

        file_path = str(file_path)
        self.wrapped.OutputActiveReportTo(file_path if file_path else None)

    def output_active_report_as_text_to(self, file_path: 'str'):
        ''' 'OutputActiveReportAsTextTo' is the original name of this method.

        Args:
            file_path (str)
        '''

        file_path = str(file_path)
        self.wrapped.OutputActiveReportAsTextTo(file_path if file_path else None)

    def get_active_report_with_encoded_images(self) -> 'str':
        ''' 'GetActiveReportWithEncodedImages' is the original name of this method.

        Returns:
            str
        '''

        method_result = self.wrapped.GetActiveReportWithEncodedImages()
        return method_result

    def output_named_report_to(self, report_name: 'str', file_path: 'str'):
        ''' 'OutputNamedReportTo' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        '''

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportTo(report_name if report_name else None, file_path if file_path else None)

    def output_named_report_as_masta_report(self, report_name: 'str', file_path: 'str'):
        ''' 'OutputNamedReportAsMastaReport' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        '''

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsMastaReport(report_name if report_name else None, file_path if file_path else None)

    def output_named_report_as_text_to(self, report_name: 'str', file_path: 'str'):
        ''' 'OutputNamedReportAsTextTo' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        '''

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsTextTo(report_name if report_name else None, file_path if file_path else None)

    def get_named_report_with_encoded_images(self, report_name: 'str') -> 'str':
        ''' 'GetNamedReportWithEncodedImages' is the original name of this method.

        Args:
            report_name (str)

        Returns:
            str
        '''

        report_name = str(report_name)
        method_result = self.wrapped.GetNamedReportWithEncodedImages(report_name if report_name else None)
        return method_result



'''_1175.py

DIN5480SplineJointDesign
'''


from mastapy._internal import constructor
from mastapy._internal.implicit import overridable
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy.detailed_rigid_connectors.splines import _1202
from mastapy._internal.python_net import python_net_import

_DIN5480_SPLINE_JOINT_DESIGN = python_net_import('SMT.MastaAPI.DetailedRigidConnectors.Splines', 'DIN5480SplineJointDesign')


__docformat__ = 'restructuredtext en'
__all__ = ('DIN5480SplineJointDesign',)


class DIN5480SplineJointDesign(_1202.StandardSplineJointDesign):
    '''DIN5480SplineJointDesign

    This is a mastapy class.
    '''

    TYPE = _DIN5480_SPLINE_JOINT_DESIGN

    __hash__ = None

    def __init__(self, instance_to_wrap: 'DIN5480SplineJointDesign.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def reference_diameter(self) -> 'float':
        '''float: 'ReferenceDiameter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ReferenceDiameter

    @property
    def addendum_modification_factor(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'AddendumModificationFactor' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.AddendumModificationFactor) if self.wrapped.AddendumModificationFactor else None

    @addendum_modification_factor.setter
    def addendum_modification_factor(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0, is_overridden)
        self.wrapped.AddendumModificationFactor = value

    @property
    def base_diameter(self) -> 'float':
        '''float: 'BaseDiameter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.BaseDiameter

    @property
    def pitch_diameter(self) -> 'float':
        '''float: 'PitchDiameter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PitchDiameter

    @property
    def minimum_form_clearance(self) -> 'float':
        '''float: 'MinimumFormClearance' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MinimumFormClearance

    @property
    def nominal_space_width(self) -> 'float':
        '''float: 'NominalSpaceWidth' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NominalSpaceWidth

    @property
    def nominal_tooth_thickness(self) -> 'float':
        '''float: 'NominalToothThickness' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NominalToothThickness
